/*!
 * gameTemplaMenu.js
 * author: Brent M. Dingle
 * last modified: 2015
 *
 * Example of a menu class and related for use with theGame singleton
 * ASIDE: menuButton should be in a separate file
 *
 * This can be done many different and better ways than this
 * Here we have assumed a lot of knowledge about other things
 * as well as the existence of various global items
 */

// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------
// 'class' menuButton											menuButton
// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------
function menuButton()
{
    // public member variables
	this.boxColor          = "rgb(200, 200, 200)";
	this.boxShadowColor    = "rgb(100, 100, 100)";
	this.x                 = 20;
	this.y                 = 120;
	this.width             = 230;
	this.height            = 40;
	this.text              = "Button Text";
	this.textColor         = "rgb(0, 0, 256)";
};

// ----------------------------------------------------------------------------
// menuButton 'class' method: coordsAreInside
// ----------------------------------------------------------------------------
menuButton.prototype.coordsAreInside = function(mouseX, mouseY)
{
    if (   ((mouseX > this.x) && (mouseX < (this.x + this.width))) 
		&& ((mouseY > this.y) && (mouseY < (this.y + this.height))) )
		return true;
	else
		return false;	
};

// ----------------------------------------------------------------------------
// menuButton class method: drawButton
// ----------------------------------------------------------------------------
menuButton.prototype.drawButton = function(menuContext)
{
    menuContext.font = "30px Verdana";   // could make this a button trait
    
    menuContext.fillStyle = this.boxShadowColor;
    menuContext.fillRect(this.x+2, this.y+2, this.width, this.height);
    menuContext.fillStyle = this.boxColor;
    menuContext.fillRect(this.x, this.y, this.width, this.height);
    menuContext.fillStyle = this.textColor;
    menuContext.fillText(this.text, this.x+5, this.y + this.height - 10);
};

// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------
// 'class' EZmenu											EZmenu
// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------
function EZmenu(backImage)
{
    //console.log("DEBUG: backImage sent = " + backImage);
    var menuBckgrndLoaded = 0; // 0 means false, private var
    this.menuBckgrndImg = new Image();
    this.menuBckgrndImg.onload = function () { 	menuBckgrndLoaded = 1; };
                                                //console.log("DEBUG: menu background loaded!" + menuBckgrndLoaded); };
    this.menuBckgrndImg.src = backImage;

    var GameTitle = new menuButton();
    GameTitle.text = "Title: The Game";  // TODO: set game name correctly
    GameTitle.y = 20;
    GameTitle.width = 270;

    var playButton = new menuButton();
    playButton.text = "Play Game";

    var creditsButton = new menuButton();
    creditsButton.text = "Credits";
    creditsButton.y = playButton.y + 1.25 * playButton.height;
    
    // ----------------------------------------------------------------------------
    // Draw the Menu Screen
    // ----------------------------------------------------------------------------
    this.DrawMenu = function()
    {
        // Init Local Canvas variables
        var menuCanvas = document.getElementById(CANVAS_MENU_ID);
        var menuContext = menuCanvas.getContext("2d");

        if (menuBckgrndLoaded == 0) // && (this.menuB1loaded != 0) && (this.menuB2loaded != 0) ...
        {
            // Aside the below assumes all other canvases and div's are NOT visible
            
            // --------------------------------------------------------------- Title Button
            GameTitle.drawButton(menuContext);
            
            // Fill text with fun gradient
            // Create gradient
            var gradient = menuContext.createLinearGradient(0,0,menuCanvas.width,0);
            gradient.addColorStop("0","magenta");
            gradient.addColorStop("0.5","blue");
            gradient.addColorStop("1.0","red");
            menuContext.fillStyle = gradient;
            menuContext.fillText("Loading...", GameTitle.x + 10, GameTitle.y + 2.5*GameTitle.height);
        }
        else // if (menuBckgrndLoaded != 0)
        {
            // draw background image
            menuContext.drawImage(this.menuBckgrndImg, 
                                  0, 0, this.menuBckgrndImg.width, this.menuBckgrndImg.height,
                                  0, 0, menuCanvas.width, menuCanvas.height);
            
            // --------------------------------------------------------------- Draw Buttons
            GameTitle.drawButton(menuContext);
            playButton.drawButton(menuContext);
            creditsButton.drawButton(menuContext);
        }
    };

    // ----------------------------------------------------------------------------
    // This REQUIRES theGame to exist as a singleton object 
    // with the getMousePos() function -- could make that function part of 
    // this class too
    // ----------------------------------------------------------------------------
    this.doMenuClick = function(evt)
    {
        var menuCanvas = document.getElementById(CANVAS_MENU_ID);
        var gameCanvas = document.getElementById(CANVAS_GAME_ID);
        var creditsCanvas = document.getElementById(CANVAS_CREDITS_ID);
        

        var mousePos = theGame.getMousePos(menuCanvas, evt);

        if ( playButton.coordsAreInside(mousePos.x, mousePos.y) == true)
        {
            gameCanvas.style.display    = "block";
            menuCanvas.style.display    = "none";
            creditsCanvas.style.display = "none";
            theGame.gameState = theGame.STATE_PLAYING;
        }
        else if ( creditsButton.coordsAreInside(mousePos.x, mousePos.y) == true)
        {
            gameCanvas.style.display    = "none";
            menuCanvas.style.display    = "none";
            creditsCanvas.style.display = "block";
            theGame.gameState = theGame.STATE_CREDITS;
        }
    };
};
